Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2017-05-28 20:11:09 +0300
committerDavid Crocker <dcrocker@eschertech.com>2017-05-28 20:11:26 +0300
commit6d41bf935c54051a97cff1c69d31ef8678292eea (patch)
tree0b6fc091873f1ef07b815063caff127edd800148 /src/MessageType.h
parent87fc280c00216f813a2da285cc2efeb71c758796 (diff)
Verison 1.19 beta 2
Improved reliability of new interface to WiFi module Added options to control thermostatic fans based on CPU and driver temperatures Support M204 S parameter for backwards compatibility Fixes to Scara kinematics Support additional axes on delta printers Added extra info to M122 repoirt
Diffstat (limited to 'src/MessageType.h')
-rw-r--r--src/MessageType.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/MessageType.h b/src/MessageType.h
index 4420031c..816a0326 100644
--- a/src/MessageType.h
+++ b/src/MessageType.h
@@ -18,7 +18,8 @@ enum MessageType
HTTP_MESSAGE, // A message that is to be sent to the web (HTTP)
TELNET_MESSAGE, // A message that is to be sent to a Telnet client
GENERIC_MESSAGE, // A message that is to be sent to the web, USB and panel
- FIRMWARE_UPDATE_MESSAGE // A message that conveys progress of a firmware update
+ FIRMWARE_UPDATE_MESSAGE, // A message that conveys progress of a firmware update
+ NETWORK_INFO_MESSAGE // A message that conveys information about the state of the network interface
};
#endif /* MESSAGETYPE_H_ */